@@ -12,9 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# pylint: disable=unused-import
-
-from opentelemetry.sdk.metrics._internal.aggregation import (  # noqa: F401
+from opentelemetry.sdk.metrics._internal.aggregation import (
     Aggregation,
     DefaultAggregation,
     DropAggregation,
@@ -22,10 +20,14 @@ from opentelemetry.sdk.metrics._internal.aggregation import (  # noqa: F401
     LastValueAggregation,
     SumAggregation,
 )
-from opentelemetry.sdk.metrics._internal.view import View  # noqa: F401
+from opentelemetry.sdk.metrics._internal.view import View
 
-__all__ = []
-for key, value in globals().copy().items():
-    if not key.startswith("_"):
-        value.__module__ = __name__
-        __all__.append(key)
+__all__ = [
+    "Aggregation",
+    "DefaultAggregation",
+    "DropAggregation",
+    "ExplicitBucketHistogramAggregation",
+    "LastValueAggregation",
+    "SumAggregation",
+    "View",
+]
